@@ -1131,10 +1131,7 @@ class PartitionDistributive(Distributive):
                                    lambda x: x[NEEDFORMAT] and x[FS] != "bind",
                                    dataPartitions))
         # if has separate /boot partition
-        if any("/boot" in mp for fs,dev,_id,mp in formatPartitions):
-            bootmp = "/boot"
-        else:
-            bootmp = "/"
+        bootmp = ["/boot", "/"]
         # format all get partition
         for fileSystem, dev, newID, mp in formatPartitions:
             if fileSystem == "swap":
@@ -1145,13 +1142,14 @@ class PartitionDistributive(Distributive):
                 if dev == self.partition:
                     self.formatPartition(dev, format=fileSystem,
                                          label=self.rootLabel,
-                                         boot= mp == bootmp)
+                                         boot= mp in bootmp)
                 else:
                     if mp == '/var/calculate':
                         self.formatPartition(dev, format=fileSystem,
                                              label="Calculate")
                     else:
-                        self.formatPartition(dev, format=fileSystem, boot= mp == bootmp)
+                        self.formatPartition(dev, format=fileSystem,
+                                             boot= mp in bootmp)
         # change system id for partitions
         changeidPartitions = map(lambda x: (x[NEWID], x[DEV], x[PARTTABLE]),
                                  filter(lambda x: x[NEWID],
