@@ -56,10 +56,10 @@ class VariableOsInstallKernelScheduler(Variable):
                                         eq='on')
 
     def get_default(self):
-        root_dev = self.Select('os_install_disk_parent',
+        root_devs = self.Select('os_install_disk_parent',
                                where='os_install_disk_mount',
-                               eq='/', limit=1)
-        if root_dev:
+                               eq='/', limit=1).split(',')
+        for root_dev in root_devs:
             dev_ssd, dev_virtual = self.Select(['os_device_ssd_set',
                                                 'os_device_virtual_set'],
                                                where='os_device_dev',
@@ -282,19 +282,16 @@ class VariableOsInstallKernelAttr(Variable):
     """
 
     def get(self):
-        # on usb-hdd install must be "delay=5"
-        attr = ""
-        rdauto = ""
-        if self.Get('os_install_root_type') == 'usb-hdd':
-            attr = " scandelay=5"
-        if self.Get('os_install_mdadm_set') == 'on':
-            attr += " domdadm"
-            rdauto = " rd.auto"
-        if self.Get('os_install_lvm_set') == 'on':
-            attr += " dolvm"
-            if not rdauto:
-                rdauto = " rd.auto"
-        return attr + rdauto
+        def generate():
+            # 5 sec for usb hdd boot
+            if self.Get('os_install_root_type') == 'usb-hdd':
+                yield "scandelay=5"
+            if (self.GetBool('os_install_mdadm_set') or
+                self.GetBool('os_install_lvm_set')):
+                yield "rd.auto"
+            yield "rd.retry=40"
+
+        return " ".join(generate())
 
 
 class VariableOsInstallKernelResume(ReadonlyVariable):
